@@ -9,11 +9,10 @@
 */
 
 #include "core.h"
-
 #include "kontactinterface_debug.h"
 
 #include <KPluginFactory>
-#include <KPluginLoader>
+#include <KPluginMetaData>
 
 #include <QDateTime>
 #include <QTimer>
@@ -21,12 +20,12 @@
 using namespace KontactInterface;
 
 //@cond PRIVATE
-class Q_DECL_HIDDEN KontactInterface::Core::Private
+class Q_DECL_HIDDEN KontactInterface::CorePrivate
 {
     Core *const q;
 
 public:
-    explicit Private(Core *qq);
+    explicit CorePrivate(Core *qq);
 
     void slotPartDestroyed(QObject *);
     void checkNewDay();
@@ -36,7 +35,7 @@ public:
     QMap<QByteArray, KParts::Part *> mParts;
 };
 
-Core::Private::Private(Core *qq)
+CorePrivate::CorePrivate(Core *qq)
     : q(qq)
     , mLastDate(QDate::currentDate())
 {
@@ -45,19 +44,16 @@ Core::Private::Private(Core *qq)
 
 Core::Core(QWidget *parent, Qt::WindowFlags f)
     : KParts::MainWindow(parent, f)
-    , d(new Private(this))
+    , d(new CorePrivate(this))
 {
-    QTimer *timer = new QTimer(this);
+    auto timer = new QTimer(this);
     connect(timer, &QTimer::timeout, this, [this]() {
         d->checkNewDay();
     });
     timer->start(1000 * 60);
 }
 
-Core::~Core()
-{
-    delete d;
-}
+Core::~Core() = default;
 
 KParts::Part *Core::createPart(const char *libname)
 {
@@ -69,31 +65,23 @@ KParts::Part *Core::createPart(const char *libname)
         return it.value();
     }
 
+
     qCDebug(KONTACTINTERFACE_LOG) << "Creating new KPart";
-
-    KPluginLoader loader(QString::fromLatin1(libname));
-    qCDebug(KONTACTINTERFACE_LOG) << loader.fileName();
-    KPluginFactory *factory = loader.factory();
-    KParts::Part *part = nullptr;
-    if (factory) {
-        part = factory->create<KParts::Part>(this);
-    }
-
-    if (part) {
-        d->mParts.insert(libname, part);
-        QObject::connect(part, &KParts::Part::destroyed, this, [this](QObject *obj) {
+    const auto result = KPluginFactory::instantiatePlugin<KParts::Part>(KPluginMetaData(QString::fromLatin1(libname)), this);
+    if (result.plugin) {
+        d->mParts.insert(libname, result.plugin);
+        QObject::connect(result.plugin, &KParts::Part::destroyed, this, [this](QObject *obj) {
             d->slotPartDestroyed(obj);
         });
     } else {
-        d->lastErrorMessage = loader.errorString();
+        d->lastErrorMessage = result.errorString;
         qCWarning(KONTACTINTERFACE_LOG) << d->lastErrorMessage;
     }
-
-    return part;
+    return result.plugin;
 }
 
 //@cond PRIVATE
-void Core::Private::slotPartDestroyed(QObject *obj)
+void CorePrivate::slotPartDestroyed(QObject *obj)
 {
     // the part was deleted, we need to remove it from the part map to not return
     // a dangling pointer in createPart
@@ -107,7 +95,7 @@ void Core::Private::slotPartDestroyed(QObject *obj)
     }
 }
 
-void Core::Private::checkNewDay()
+void CorePrivate::checkNewDay()
 {
     if (mLastDate != QDate::currentDate()) {
         Q_EMIT q->dayChanged(QDate::currentDate());
